### -*- coding: utf-8 -*- #############################################
#######################################################################
"""installMain script for the Zope 3 based ng.site.content.install package

$Id: product.py 49265 2008-01-08 12:18:26Z cray $
"""
__author__  = "Yegor Shershnev, 2007"
__license__ = "GPL"
__version__ = "$Revision: 49265 $"


from zope.app.folder.folder import Folder

from zope.app.component.hooks import setSite
from zope.app.component import site
from zope.app.container.interfaces import IContainer


def installMain(context, **kw):
    """ Регистрирует context как папку Main, где впоследствии будет храниться
        содержимое сайта в виде экземпляров ng.content.article
    """
    context.title = kw['title']
    context.author = kw['author']
    
    sm = context.getSiteManager()
    sm.registerUtility(context, provided=IContainer, name=u'Main')

    return "Success"



### -*- coding: utf-8 -*- #############################################
#######################################################################
"""InstallCatalog script for the Zope 3 based ng.site.content.install package

$Id: product.py 49265 2008-01-08 12:18:26Z cray $
"""
__author__  = "Yegor Shershnev, 2007"
__license__ = "GPL"
__version__ = "$Revision: 49265 $"

from zope.app.folder.folder import Folder

from zope.app.component.hooks import setSite
from zope.app.component import site

from zope.app.catalog.catalog import Catalog
from zope.app.catalog.interfaces import ICatalog

from zope.app.catalog.text import TextIndex
from zope.app.catalog.field import FieldIndex

from zc.catalog.catalogindex import SetIndex, ValueIndex 
from zc.catalog.interfaces import IIndexValues

from ng.site.content.search.interfaces import ISearch

def installCatalog(context, **kw):
    """ Install Catalog and all indexes that them need """
    
    sm = context.getSiteManager()
    sm['Catalog'] = Catalog()
    sm.registerUtility(sm['Catalog'], provided=ICatalog, name='catalog')

    sm['Catalog']['abstract'] = TextIndex(field_name=u'abstract', interface=ISearch, field_callable=False)
    sm['Catalog']['backkeyword'] = SetIndex(field_name=u'backkeyword',interface=ISearch, field_callable=False)
    sm['Catalog']['backname'] = SetIndex(field_name=u'backname',interface=ISearch, field_callable=False)
    sm['Catalog']['body'] = TextIndex(field_name=u'body', interface=ISearch, field_callable=False)
    sm['Catalog']['common'] = TextIndex(field_name=u'common', interface=ISearch, field_callable=False)
    sm['Catalog']['keyword'] = SetIndex(field_name=u'keyword',interface=ISearch, field_callable=False)
    sm['Catalog']['klass'] = FieldIndex(field_name=u'klass', interface=ISearch, field_callable=False)
    sm['Catalog']['mtime'] = FieldIndex(field_name=u'mtime', interface=ISearch, field_callable=False)
    sm['Catalog']['name'] = SetIndex(field_name=u'name', interface=ISearch, field_callable=False)
    sm['Catalog']['reference'] = SetIndex(field_name=u'reference',interface=ISearch, field_callable=False)
    sm['Catalog']['urlpath'] = FieldIndex(field_name=u'urlpath',interface=ISearch, field_callable=False)

    sm.registerUtility(sm['Catalog']['backkeyword'],provided=IIndexValues,name='backkeyword')    
    sm.registerUtility(sm['Catalog']['backname'],provided=IIndexValues,name='backname')    
    sm.registerUtility(sm['Catalog']['keyword'],provided=IIndexValues,name='keyword')    

    return "Success"



### -*- coding: utf-8 -*- #############################################
#######################################################################
"""installObjectQueue script for the Zope 3 based
ng.site.content.install package

$Id: install_quota.py 51196 2008-06-26 14:16:21Z cray $
"""
__author__  = "Andrey Orlov, 2008"
__license__ = "GPL"
__version__ = "$Revision: 51196 $"

from zope.app.file.interfaces import IImage
from zope.app.file.image import Image
from ng.app.quota.interfaces import IQuota
from ng.app.quota.quota import Quota

def installQuota(context, **kw):
    """ Создаёт в сайт-менеджере Quota и регистрирует её под
        необходимым интерфейсом
    """
    sm = context.getSiteManager()
    
    quota = sm[u'quota'] = Quota()
    
    sm.registerUtility(quota, provided=IQuota)

    return "Success"



### -*- coding: utf-8 -*- #############################################
#######################################################################                                                 #

"""Interfaces for the Zope 3 based search package

$Id: interfaces.py 51196 2008-06-26 14:16:21Z cray $
"""
__author__  = "Andrey Orlov, 2007-02-20"
__license__ = "GPL"
__version__ = "$Revision: 51196 $"
__date__ = "$Date: 2008-06-26 18:16:21 +0400 (Чтв, 26 Июн 2008) $"
 
from zope.interface import Interface
from zope.schema import Text, TextLine, Datetime, Tuple, Set, Field

class ISearchable(Interface) :
    """ Interface for searchable objects """

class ISearchClass(Interface) :
    """Interface for index objects"""

    klass = Text()

class ISearchName(Interface) :
    """Interface for index objects"""

    name = Text()

class ISearchBackName(Interface) :
    """Interface for index objects"""

    backname = Text()

class ISearchBackKeyword(Interface) :
    """Interface for index objects"""

    backkeyword = Text()

class ISearchKeyword(Interface) :
    """Interface for index objects"""

    keyword = Text()
                
class ISearch(Interface) :
    """ Interface for common object search """

    title = Text()
    
    abstract = Text()
    
    body = Text()
    
    common = Text()

    keywords = Text()

    klass = Text()

    name = Text()

    prefix = Text()
    
    path = Text()

    backname = Text()            

    mtime = Datetime()

    urlpath = Text()

    reference = Tuple()        
    


### -*- coding: utf-8 -*- #############################################
#######################################################################
"""installRSS script for the Zope 3 based ng.site.content.install package

$Id: install_rss.py 51196 2008-06-26 14:16:21Z cray $
"""
__author__  = "Yegor Shershnev, 2008"
__license__ = "GPL"
__version__ = "$Revision: 51196 $"

from zope.app.file.interfaces import IImage
from zope.app.file.image import Image
from ng.app.rss.interfaces import IRSS
from ng.app.rss.rss import RSS

def installRSS(context, **kw):
    """ Создаёт в сайт-менеждере RSS и регистрирует его
    """
    sm = context.getSiteManager()
    
    rss = sm[u'RSS'] = RSS()
    
    sm.registerUtility(sm[u'RSS'], provided=IRSS)
    
    return "Success"



### -*- coding: utf-8 -*- #############################################
#######################################################################
"""Dwitchable markers

$Id: interfaces.py 51196 2008-06-26 14:16:21Z cray $
"""
__author__  = "Andrey Orlov"
__license__ = "GPL"
__version__ = "$Revision: 51196 $"
__date__ = "$Date: 2008-06-26 18:16:21 +0400 (Чтв, 26 Июн 2008) $"
 
from ks.interfaceswitcher.interfaces import IInterfaceSwitcherAble
from ng.content.article.interfaces import IDocFormatSwitcher

class IArticleDesignSwitcher(IInterfaceSwitcherAble):
    "Default Design"
    pass

    
class IArticleDivided(IArticleDesignSwitcher) :
    "Divided Design"
    pass

class IArticlePage(IArticleDesignSwitcher):
    "Page Design"
    pass

class IArticleREST(IDocFormatSwitcher) :
    "Restructured text data"
    pass

class IArticleST(IDocFormatSwitcher):
    "Structured text data"
    pass

class IArticleASIS(IDocFormatSwitcher):
    "Preformated Text"
    pass

class IArticleHTML(IDocFormatSwitcher):
    "HTML text data"
    pass


class IDivisionDesignSwitcher(IInterfaceSwitcherAble):
    "Default Design"
    pass

class IDivisionDictionarySwitcher(IDivisionDesignSwitcher) :
    "Dictionary design "

class IDivisionItemSwitcher(IDivisionDesignSwitcher) :
    "Item design "
    
    



### -*- coding: utf-8 -*- #############################################
#######################################################################
"""RubricDescription class for the Zope 3 based ng.site.content.install package

$Id: rubricdescription.py 51196 2008-06-26 14:16:21Z cray $
"""
__author__  = "Yegor Shershnev, 2008"
__license__ = "GPL"
__version__ = "$Revision: 51196 $"


from zope.interface import implements
from interfaces import IRubricDescription
from persistent import Persistent
from zope.schema import Field


class RubricDescription(object):
    """ RubricDescription
    """
    
    implements(IRubricDescription)
    
    name = u''
    
    title = u''
    
    abstract = u''



### -*- coding: utf-8 -*- #############################################
#######################################################################
""" OrderedContainer Adapter to IPagerSource Interface

$Id: readcontainer2pagersourceadapter.py 51196 2008-06-26 14:16:21Z cray $
"""
__author__  = "Andrey Orlov, 2007"
__license__ = "GPL"
__version__ = "$Revision: 51196 $"

from zope.interface import implements,Interface
from zope.component import adapts
from ng.adapter.pager.interfaces import IPagerSource
from zope.cachedescriptors.property import CachedProperty
from zope.app.container.interfaces import IReadContainer
from ng.content.article.adapter.containeradapter import ContentContainerAdapter

class ReadContainer2PagerSourceAdapter(ContentContainerAdapter):
    __doc__ = __doc__

    implements(IPagerSource)
    adapts(IReadContainer)

    def keys(self) :
        return list(super(ReadContainer2PagerSourceAdapter,self).keys())
        



### -*- coding: utf-8 -*- #############################################
#######################################################################
"""Product class for the Zope 3 based product package

$Id: convertable2titlesubscriber.py 51196 2008-06-26 14:16:21Z cray $
"""
__author__  = "Andrey Orlov, 2007"
__license__ = "GPL"
__version__ = "$Revision: 51196 $"

from zope.component import adapts
from ng.adapter.ianytitle.anytitlesubscriberbase import AnyTitleSubscriberBase
from ng.app.converter.object2psadapter.interfaces import IAttributeConvertable, IPropertySheet

class Convertable2TitleSubscriber(AnyTitleSubscriberBase) :
    adapts(IAttributeConvertable)
    order = 3
            
    @property
    def title(self) :
        return IPropertySheet(self.context).get('title',u"")



### -*- coding: utf-8 -*- #############################################
#######################################################################
"""installSmartImage script for the Zope 3 based ng.site.content.install
package

$Id: product.py 49265 2008-01-08 12:18:26Z cray $
"""
__author__  = "Yegor Shershnev, 2007"
__license__ = "GPL"
__version__ = "$Revision: 49265 $"


from zope.app.folder.folder import Folder

from zope.app.component.hooks import setSite
from zope.app.component import site

from ks.smartimage.smartimagecache.interfaces import ISmartImageProp
from ks.smartimage.smartimagecache.smartimagecache import SmartImageCache
from ks.smartimage.smartimagecache.scale import Scale


def installSmartImage(context, **kw):
    """ Устанавливает и настраивает продукт SmartImage
    """
    sm = context.getSiteManager()
    
    sm[u'SmartImageCache'] = SmartImageCache()
    
    sic = sm[u'SmartImageCache']

    sic.scales = (Scale(u'small', 40, 50), Scale(u'big', 400, 500),)

    sic.format = u'GIF'
    sic.scale = u'big'
    sic.basepath = u'/' + context.__name__

    sm.registerUtility(sm[u'SmartImageCache'], provided=ISmartImageProp)

    return "Success"



### -*- coding: utf-8 -*- #############################################
#######################################################################
"""Product class for the Zope 3 based product package

$Id: doctitle2titlesubscriber.py 51196 2008-06-26 14:16:21Z cray $
"""
__author__  = "Andrey Orlov, 2007"
__license__ = "GPL"
__version__ = "$Revision: 51196 $"

from zope.component import adapts
from ng.content.article.interfaces import IDocTitle
from ng.adapter.ianytitle.anytitlesubscriberbase import AnyTitleSubscriberBase

class DocTitle2TitleSubscriber(AnyTitleSubscriberBase) :

    adapts(IDocTitle)
    order = 4
        
    @property
    def title(self) :
        return IDocTitle(self.context).title or u""



### -*- coding: utf-8 -*- #############################################
#######################################################################
"""installObjectQueue script for the Zope 3 based
ng.site.content.install package

$Id: install_objectqueue.py 51196 2008-06-26 14:16:21Z cray $
"""
__author__  = "Yegor Shershnev, 2008"
__license__ = "GPL"
__version__ = "$Revision: 51196 $"

from zope.app.file.interfaces import IImage
from zope.app.file.image import Image
from ng.app.objectqueue.interfaces import IObjectQueue
from ng.app.objectqueue.objectqueue import ObjectQueue

def installObjectQueue(context, **kw):
    """ Создаёт в сайт-менеджере ObjectQueue и регистрирует её под
        необходимым интерфейсом
    """
    sm = context.getSiteManager()
    
    oq = sm[u'objectqueue'] = ObjectQueue()
    
    sm.registerUtility(oq, provided=IObjectQueue)

    return "Success"



### -*- coding: utf-8 -*- #############################################
#######################################################################
"""installRegistry script for the Zope 3 based ng.site.content.install package

$Id: install_registry.py 51196 2008-06-26 14:16:21Z cray $
"""
__author__  = "Yegor Shershnev, 2008"
__license__ = "GPL"
__version__ = "$Revision: 51196 $"


from zope.app.intid.interfaces import IIntIds
from zope.app.intid import IntIds
from ng.app.registry.registry import Registry
from ng.app.registry.registryint import RegistryInt
from ng.app.registry.registrytextline import RegistryTextLine
from ng.app.registry.interfaces import IRegistry


def installRegistry(context, **kw):
    """ Устанавливает в сайт-менеджере продукт ng.app.registry, регистрируем
        его и наполняем необходимым содержимым
    """
    sm = context.getSiteManager()
    sm[u'registry'] = Registry()
    sm.registerUtility(sm[u'registry'], provided=IRegistry)
    
    sm[u'registry'][u'pager_orphan'] = RegistryInt()
    sm[u'registry'][u'pager_orphan'].data = 3
    
    sm[u'registry'][u'pager_size'] = RegistryInt()
    sm[u'registry'][u'pager_size'].data = 10
    ## sm[u'registry'][u'pager_revert'] = RegistryBool()

    sm[u'registry'][u'pager_rss'] = RegistryTextLine()
    sm[u'registry'][u'pager_size'].data = '@@rssview.html'

    sm[u'registry'][u'datetimeformat'] = RegistryTextLine()
    sm[u'registry'][u'datetimeformat'].data = '%Y-%m-%d %H:%M'
    
    return "Success"



### -*- coding: utf-8 -*- #############################################
#######################################################################
"""installSiteManager script for the Zope 3 based ng.site.content.install
package

$Id: product.py 49265 2008-01-08 12:18:26Z cray $
"""
__author__  = "Yegor Shershnev, 2007"
__license__ = "GPL"
__version__ = "$Revision: 49265 $"


from zope.app.folder.folder import Folder

from zope.app.component.hooks import setSite
from zope.app.component import site


def installSiteManager(context, **kw):
    """ Преобразует папку контекста в сайт
    """
    # Создаём локальный менеджер сайта
    sm = site.LocalSiteManager(context)
    # Устанавливаем созданный менеджер сайта в контекст
    context.setSiteManager(sm)
    # Делаем контекст сайтом
    setSite(context)
    # Выполнено успешно
    return "Success"



### -*- coding: utf-8 -*- #############################################
#######################################################################
"""Adapter article to rss-entry

$Id: article2rssentryadapter.py 51196 2008-06-26 14:16:21Z cray $
"""
__author__  = "Andrey Orlov, 2008"
__license__ = "GPL"
__version__ = "$Revision: 51196 $"

from zope.app.zapi import getUtility
from zope.component import ComponentLookupError
from zope.traversing.browser import absoluteURL
from ng.app.converter.object2psadapter.interfaces import IPropertySheet
from ng.adapter.mtime.interfaces import IMTime
from persistent.interfaces import IPersistent
from zope.security.proxy import removeSecurityProxy
import uuid

class Article2RSSEntryAdapter(object) :
    """ Adapter article to rss-entry """
    def __init__(self,context,request) :
        ps = IPropertySheet(context)
        self.title = ps['title']
        self.updated = IMTime(context).strftime("%Y-%m-%dT%H-%M-%SZ")
        self.summary = ps['summary'] or ps['autosummary']
        self.id = uuid.uuid3(uuid.NAMESPACE_OID,IPersistent(removeSecurityProxy(context))._p_oid).urn
        self.link = absoluteURL(context,request)


    title = ""
    updated = ""
    summary = ""
    id = ""
    link = ""
    



#!/usr/bin/env python
### -*- coding: utf-8 -*- #############################################
#######################################################################
from setuptools import setup, find_packages

setup(
    name='ng.site.content',
    version='1.1.1',
    url='http://www.dreambot.ru/product/DreamBotSite/ng.site.content/',
    author='Andrey Orlov',
    author_email='dbdt@dreambot.ru',
    license='GPL v2.1',
    classifiers=['Environment :: Web Environment',
                 'Intended Audience :: Developers',
                 'License :: OSI Approved :: GNU General Public License (GPL)',
                 'Programming Language :: Python',
                 'Operating System :: OS Independent',
                 'Topic :: Internet :: WWW/HTTP',
                 'Framework :: Zope3',
                 ],
    description="Simple content-site",
    long_description=(open('README.txt').read() + '\n\n' + open('CHANGES.txt').read()),
    packages=find_packages('src'),
    package_dir={'': 'src'},
    namespace_packages=['ng','ng.site'],
    include_package_data=True,
    install_requires=[x.strip() for x in open("DEPENDENCES.txt").read().split("\n") if x.strip()],
    zip_safe=False,
    )



### -*- coding: utf-8 -*- #############################################
#######################################################################
"""installFuzzyTraverser script for the Zope 3 based
ng.site.content.install package

$Id: product.py 49265 2008-01-08 12:18:26Z cray $
"""
__author__  = "Andrey Orlov, 2008"
__license__ = "GPL"
__version__ = "$Revision: 49265 $"


from ng.fuzzytraverser.fuzzytraverserproperties.fuzzytraverserproperties import FuzzyTraverserProperties
from ng.fuzzytraverser.fuzzytraverserproperties.interfaces import IFuzzyTraverserProperties


def installFuzzyTraverser(context, **kw):
    """ Install FuzzyTraverserProperty into site manager """

    sm = context.getSiteManager()
    sm[u'FuzzyTraverserProperties'] = FuzzyTraverserProperties()
    sm[u'FuzzyTraverserProperties'].on  = True
    sm[u'FuzzyTraverserProperties'].use = True
    
    sm.registerUtility(sm[u'FuzzyTraverserProperties'], provided=IFuzzyTraverserProperties)

    return "Success"



### -*- coding: utf-8 -*- #############################################
#######################################################################                                                 #

"""Class adapter for the Zope 3 based search package

$Id: searchbackkeywordadapter.py 51196 2008-06-26 14:16:21Z cray $
"""
__author__  = "Andrey Orlov, 2007-02-20"
__license__ = "GPL"
__version__ = "$Revision: 51196 $"
__date__ = "$Date: 2008-06-26 18:16:21 +0400 (Чтв, 26 Июн 2008) $"
 
from zope.interface import Interface
from zope.schema import Text, TextLine, Datetime, Tuple, Set, Field
import re


class SearchBackKeywordAdapter(object) :
    """Interface for index objects"""

    def __init__(self,ob) :
        self.backkeyword = [re.sub("\s+"," ",x).strip().lower() for x in re.findall("\[keyword:(?P<name>[^:\]]+(?: :[^\]]+)?)",ob.common)]
